Seantis People
==============

A list of people, optionally organized by organisations and positions.

Alternatives
------------

Close to our requirements (but no cigar):
https://github.com/collective/collective.contact.core

Requirements
------------

-  Python 2.7
-  Plone 4.3+
-  Linux / Posix ( Windows may or may not work )

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.people.png   
  :target: https://travis-ci.org/seantis/seantis.people
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.people/badge.png?branch=master
  :target: https://coveralls.io/r/seantis/seantis.people?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://pypip.in/v/seantis.people/badge.png
  :target: https://crate.io/packages/seantis.people
  :alt: Latest PyPI Release

License
-------
seantis.people is released under GPL v2
